@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.10 1999/09/08 22:08:44 bkorb Exp $
+ *  $Id: autoopts.c,v 2.13 2000/03/21 14:25:09 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -1053,9 +1053,9 @@ optionGet( tOptions*   pOpts, int argCt, char** argVect )
     const char*
 optionVersion( void )
 {
-    static const char zVersion[] = STR( AO_CURRENT ) ":"
-                                   STR( AO_REVISION ) ":"
-                                   STR( AO_AGE );
+    static const char zVersion[] =
+        STR( AO_ANNOUNCE_LEVEL );
+
     return zVersion;
 }
 
@@ -1064,7 +1064,7 @@ optionVersion( void )
  *
  *  Make sure that the argument list passes our consistency tests.
  */
-    const char*
+    STATIC int
 checkConsistency( tOptions* pOpts, int argCt )
 {
     int       errCt = 0;
@@ -1080,85 +1080,101 @@ checkConsistency( tOptions* pOpts, int argCt )
      *  THEN it is time to call usage exit.
      */
     if (errCt != 0)
-	(*pOpts->pUsageProc)( pOpts, EXIT_FAILURE );
+        (*pOpts->pUsageProc)( pOpts, EXIT_FAILURE );
 
     /*
      *  FOR each of "oCt" options, ...
      */
     for (;;) {
-	tSCC zNotEnough[] = "ERROR:  The %s option must appear %d times\n";
-	tSCC zNeedOne[]   = "ERROR:  The %s option is required\n";
+        tSCC zNotEnough[] = "ERROR:  The %s option must appear %d times\n";
+        tSCC zNeedOne[]   = "ERROR:  The %s option is required\n";
 
-	const int*  pMust = pOD->pOptMust;
-	const int*  pCant = pOD->pOptCant;
+        const int*  pMust = pOD->pOptMust;
+        const int*  pCant = pOD->pOptCant;
 
-	/*
-	 *  IF the current option was provided on the command line
-	 *  THEN ensure that any "MUST" requirements are not
-	 *       "DEFAULT" (unspecified) *AND* ensure that any
-	 *       "CANT" options have not been SET or DEFINED.
-	 */
-	if (SELECTED_OPT(pOD)) {
-	    if (pMust != (const int*)NULL) for (;;) {
-		tOptDesc*  p = pOpts->pOptDesc + *(pMust++);
-		if (UNUSED_OPT(p)) {
-		    const tOptDesc* pN = pOpts->pOptDesc + pMust[-1];
-		    errCt++;
-		    fprintf( stderr, zReqFmt, pOD->pz_Name, pN->pz_Name );
-		}
-		
-		if (*pMust == NO_EQUIVALENT)
-		    break;
-	    }
-	    
-	    if (pCant != (const int*)NULL) for (;;) {
-		tOptDesc*  p = pOpts->pOptDesc + *(pCant++);
-		if (SELECTED_OPT(p)) {
-		    const tOptDesc* pN = pOpts->pOptDesc + pCant[-1];
-		    errCt++;
-		    fprintf( stderr, zCantFmt, pOD->pz_Name, pN->pz_Name );
-		}
+        /*
+         *  IF the current option was provided on the command line
+         *  THEN ensure that any "MUST" requirements are not
+         *       "DEFAULT" (unspecified) *AND* ensure that any
+         *       "CANT" options have not been SET or DEFINED.
+         */
+        if (SELECTED_OPT(pOD)) {
+            if (pMust != (const int*)NULL) for (;;) {
+                tOptDesc*  p = pOpts->pOptDesc + *(pMust++);
+                if (UNUSED_OPT(p)) {
+                    const tOptDesc* pN = pOpts->pOptDesc + pMust[-1];
+                    errCt++;
+                    fprintf( stderr, zReqFmt, pOD->pz_Name, pN->pz_Name );
+                }
+                
+                if (*pMust == NO_EQUIVALENT)
+                    break;
+            }
+            
+            if (pCant != (const int*)NULL) for (;;) {
+                tOptDesc*  p = pOpts->pOptDesc + *(pCant++);
+                if (SELECTED_OPT(p)) {
+                    const tOptDesc* pN = pOpts->pOptDesc + pCant[-1];
+                    errCt++;
+                    fprintf( stderr, zCantFmt, pOD->pz_Name, pN->pz_Name );
+                }
 
-		if (*pCant == NO_EQUIVALENT)
-		    break;
-	    }
-	}
+                if (*pCant == NO_EQUIVALENT)
+                    break;
+            }
+        }
 
-	/*
-	 *  IF       this option is not equivalenced to another,
-	 *        OR it is equivalenced to itself (is the equiv. root)
-	 *    AND it does not occur often enough
-	 *  THEN note the error
-	 */
-	if (  (  (pOD->optEquivIndex == NO_EQUIVALENT)
-	      || (pOD->optEquivIndex == pOD->optIndex) )
+        /*
+         *  IF       this option is not equivalenced to another,
+         *        OR it is equivalenced to itself (is the equiv. root)
+         *    AND it does not occur often enough
+         *  THEN note the error
+         */
+        if (  (  (pOD->optEquivIndex == NO_EQUIVALENT)
+              || (pOD->optEquivIndex == pOD->optIndex) )
            && (pOD->optOccCt <  pOD->optMinCt)  )  {
 
-	    errCt++;
-	    if (pOD->optMinCt > 1)
-		fprintf( stderr, zNotEnough, pOD->pz_Name, pOD->optMinCt );
-	    else fprintf( stderr, zNeedOne, pOD->pz_Name );
-	}
+            errCt++;
+            if (pOD->optMinCt > 1)
+                fprintf( stderr, zNotEnough, pOD->pz_Name, pOD->optMinCt );
+            else fprintf( stderr, zNeedOne, pOD->pz_Name );
+        }
 
-	if (--oCt <= 0)
-	    break;
-	pOD++;
+        if (--oCt <= 0)
+            break;
+        pOD++;
     }
 
     /*
-     *  IF we are stopping on errors AND no arguments can be left over,
-     *     AND we have left over arguments, THEN usage exit.
+     *  IF we are stopping on errors, check to see if any remaining
+     *  arguments are required to be there or prohibited from being there.
      */
-    if (  (  (pOpts->fOptSet & (OPTPROC_NO_ARGS | OPTPROC_ERRSTOP))
-          == (OPTPROC_NO_ARGS | OPTPROC_ERRSTOP) )
-       && (argCt > pOpts->curOptIdx)) {
-        fprintf( stderr, "%s: Command line arguments not allowed\n",
-                 pOpts->pzProgName );
-        (*pOpts->pUsageProc)( pOpts, EXIT_FAILURE );
+    if ((pOpts->fOptSet & OPTPROC_ERRSTOP) != 0) {
+
+        /*
+         *  Check for prohibition
+         */
+        if ((pOpts->fOptSet & OPTPROC_NO_ARGS) != 0) {
+            if (argCt > pOpts->curOptIdx) {
+                fprintf( stderr, "%s: Command line arguments not allowed\n",
+                         pOpts->pzProgName );
+                ++errCt;
+            }
+        }
+
+        /*
+         *  ELSE not prohibited, check for being required
+         */
+        else if ((pOpts->fOptSet & OPTPROC_ARGS_REQ) != 0) {
+            if (argCt <= pOpts->curOptIdx) {
+                fprintf( stderr, "%s: Command line arguments required\n",
+                         pOpts->pzProgName );
+                ++errCt;
+            }
+        }
     }
 
-    if (errCt != 0)
-        (*pOpts->pUsageProc)( pOpts, EXIT_FAILURE );
+    return errCt;
 }
 
 
@@ -1172,12 +1188,21 @@ optionProcess( tOptions*  pOpts, int argCt, char** argVect )
     tOptDesc* pOD;
     int       errCt = 0;
 
-    if (pOpts->structVersion != OPTIONS_STRUCT_VERSION) {
+    /*
+     *  IF the struct version is not the current, and also
+     *     either too large (?!) or too small,
+     *  THEN emit error message and fail-exit
+     */
+    if (  ( pOpts->structVersion  != OPTIONS_STRUCT_VERSION )
+       && (  (pOpts->structVersion > OPTIONS_STRUCT_VERSION )
+          || (pOpts->structVersion < MIN_OPTION_VERSION     )
+       )  )  {
         tSCC zBadVer[] = "Automated Options Processing Error!\n"
-            "\toptionProcess was called by %s with structure version %d\n"
-            "\tThis library was compiled with version "
-            STR( OPTIONS_STRUCT_VERSION ) "\n";
-        fprintf( stderr, zBadVer, argVect[0], pOpts->structVersion );
+            "\toptionProcess was called by %s with structure version %d.%d\n"
+            "\tThis library was compiled with version %d.%d\n";
+        fprintf( stderr, zBadVer, argVect[0],
+                 NUM_TO_VER( pOpts->structVersion ),
+                 NUM_TO_VER( OPTIONS_STRUCT_VERSION ));
         exit( EXIT_FAILURE );
     }
 
@@ -1240,8 +1265,11 @@ optionProcess( tOptions*  pOpts, int argCt, char** argVect )
      *  IF we are checking for errors,
      *  THEN look for too few occurrences of required options
      */
-    if ((pOpts->fOptSet & OPTPROC_ERRSTOP) != 0)
-	checkConsistency( pOpts, argCt );
+    if ((pOpts->fOptSet & OPTPROC_ERRSTOP) != 0) {
+        errCt += checkConsistency( pOpts, argCt );
+        if (errCt != 0)
+            (*pOpts->pUsageProc)( pOpts, EXIT_FAILURE );
+    }
 
     return pOpts->curOptIdx;
 }
