@@ -2,17 +2,17 @@
 
 /* snprintfv.c --- printf clone for argv arrays */
 
-/* Author:	       Gary V. Vaughan <gary@oranda.demon.co.uk>
- * Maintainer:	       Gary V. Vaughan <gary@oranda.demon.co.uk>
+/* Author:	       Gary V. Vaughan <gvv@techie.com>
+ * Maintainer:	       Gary V. Vaughan <gvv@techie.com>
  * Created:	       Fri Nov 13 11:23:23 1998
- * Last Modified:      Thu Jul 22 09:53:46 1999
- *            by:      Gary V. Vaughan <gary@oranda.demon.co.uk>
+ * Last Modified:      Thu Apr  6 02:20:12 2000
+ *            by:      Gary V. Vaughan <gvv@techie.com>
  * ---------------------------------------------------------------------
- * @(#) $Id: snprintfv.c,v 1.3 1999/08/30 17:24:55 bkorb Exp $
+ * @(#) $Id$
  * ---------------------------------------------------------------------
  */
 
-/* Copyright (C) 1998, 1999 Gary V. Vaughan */
+/* Copyright (C) 1998, 1999, 2000 Gary V. Vaughan */
 
 /* This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -237,6 +237,7 @@ parser_init (pparser)
     return pparser;
 }
 
+#if 0 /* Not actually used right now... */
 /* Create, initialise and return a new printfv_parser structure. */
 static inline printfv_parser*
 parser_new PARAMS((void))
@@ -248,6 +249,7 @@ parser_new PARAMS((void))
 
     return pparser;
 }
+#endif
 
 static void
 parser_delete (parser)
@@ -1095,7 +1097,7 @@ snv_vsprintf (buffer, format, ap)
     if (count_or_errorcode >= 0)
     {
         /* Terminate with an EOS without incrementing the counter. */
-        count_or_errorcode = (bufputc(EOS, &out) != EOF)
+        count_or_errorcode = (stream_put(EOS, &out) != EOF)
 	                   ? count_or_errorcode : EOF;
     }
 
@@ -1131,7 +1133,7 @@ sprintfv (buffer, format, args)
     if (count_or_errorcode >= 0)
     {
         /* Terminate with an EOS without incrementing the counter. */
-        count_or_errorcode = (bufputc(EOS, &out) != EOF)
+        count_or_errorcode = (stream_put(EOS, &out) != EOF)
 	                   ? count_or_errorcode : EOF;
     }
 
@@ -1206,7 +1208,7 @@ snv_vsnprintf (buffer, limit, format, ap)
     if (count_or_errorcode >= 0)
     {
         /* Terminate with an EOS without incrementing the counter. */
-        count_or_errorcode = (bufputc(EOS, &out) != EOF)
+        count_or_errorcode = (stream_put(EOS, &out) != EOF)
 	                   ? count_or_errorcode : EOF;
     }
 
@@ -1245,7 +1247,7 @@ snprintfv (buffer, limit, format, args)
     if (count_or_errorcode >= 0)
     {
         /* Terminate with an EOS without incrementing the counter. */
-        count_or_errorcode = (bufputc(EOS, &out) != EOF)
+        count_or_errorcode = (stream_put(EOS, &out) != EOF)
 	                   ? count_or_errorcode : EOF;
     }
 
