@@ -2,13 +2,13 @@
 
 /* snprintfv-test.c ---  */
 
-/* Author:	       Gary V. Vaughan <gary@oranda.demon.co.uk>
- * Maintainer:	       Gary V. Vaughan <gary@oranda.demon.co.uk>
+/* Author:	       Gary V. Vaughan <gvv@techie.com>
+ * Maintainer:	       Gary V. Vaughan <gvv@techie.com>
  * Created:	       Fri Nov 13 16:51:38 1998
  * Last Modified:      Thu Sep 23 15:08:09 1999
  *            by:      Gary V. Vaughan <garyv@samhain.aethos.co.uk>
  * ---------------------------------------------------------------------
- * @(#) $Id: snprintfv-test.c,v 1.3 1999/09/24 16:31:22 bkorb Exp $
+ * @(#) $Id$
  * ---------------------------------------------------------------------
  */
 
@@ -56,7 +56,7 @@
 #include "filament.h"
 
 #ifndef AUTHOR
-#define AUTHOR		"Gary V. Vaughan <gary@oranda.demon.co.uk>"
+#define AUTHOR		"Gary V. Vaughan <gvv@techie.com>"
 #endif
 
 #ifndef EOS
